/*******************************************************************************
* File Name: CLK_4MHZ.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_CLK_4MHZ_H)
#define CY_CLOCK_CLK_4MHZ_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_20 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void CLK_4MHZ_Start(void) ;
void CLK_4MHZ_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void CLK_4MHZ_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void CLK_4MHZ_StandbyPower(uint8 state) ;
void CLK_4MHZ_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 CLK_4MHZ_GetDividerRegister(void) ;
void CLK_4MHZ_SetModeRegister(uint8 modeBitMask) ;
void CLK_4MHZ_ClearModeRegister(uint8 modeBitMask) ;
uint8 CLK_4MHZ_GetModeRegister(void) ;
void CLK_4MHZ_SetSourceRegister(uint8 clkSource) ;
uint8 CLK_4MHZ_GetSourceRegister(void) ;
#if defined(CLK_4MHZ__CFG3)
void CLK_4MHZ_SetPhaseRegister(uint8 clkPhase) ;
uint8 CLK_4MHZ_GetPhaseRegister(void) ;
#endif /* defined(CLK_4MHZ__CFG3) */

#define CLK_4MHZ_Enable()                       CLK_4MHZ_Start()
#define CLK_4MHZ_Disable()                      CLK_4MHZ_Stop()
#define CLK_4MHZ_SetDivider(clkDivider)         CLK_4MHZ_SetDividerRegister(clkDivider, 1u)
#define CLK_4MHZ_SetDividerValue(clkDivider)    CLK_4MHZ_SetDividerRegister((clkDivider) - 1u, 1u)
#define CLK_4MHZ_SetMode(clkMode)               CLK_4MHZ_SetModeRegister(clkMode)
#define CLK_4MHZ_SetSource(clkSource)           CLK_4MHZ_SetSourceRegister(clkSource)
#if defined(CLK_4MHZ__CFG3)
#define CLK_4MHZ_SetPhase(clkPhase)             CLK_4MHZ_SetPhaseRegister(clkPhase)
#define CLK_4MHZ_SetPhaseValue(clkPhase)        CLK_4MHZ_SetPhaseRegister((clkPhase) + 1u)
#endif /* defined(CLK_4MHZ__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define CLK_4MHZ_CLKEN              (* (reg8 *) CLK_4MHZ__PM_ACT_CFG)
#define CLK_4MHZ_CLKEN_PTR          ((reg8 *) CLK_4MHZ__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define CLK_4MHZ_CLKSTBY            (* (reg8 *) CLK_4MHZ__PM_STBY_CFG)
#define CLK_4MHZ_CLKSTBY_PTR        ((reg8 *) CLK_4MHZ__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define CLK_4MHZ_DIV_LSB            (* (reg8 *) CLK_4MHZ__CFG0)
#define CLK_4MHZ_DIV_LSB_PTR        ((reg8 *) CLK_4MHZ__CFG0)
#define CLK_4MHZ_DIV_PTR            ((reg16 *) CLK_4MHZ__CFG0)

/* Clock MSB divider configuration register. */
#define CLK_4MHZ_DIV_MSB            (* (reg8 *) CLK_4MHZ__CFG1)
#define CLK_4MHZ_DIV_MSB_PTR        ((reg8 *) CLK_4MHZ__CFG1)

/* Mode and source configuration register */
#define CLK_4MHZ_MOD_SRC            (* (reg8 *) CLK_4MHZ__CFG2)
#define CLK_4MHZ_MOD_SRC_PTR        ((reg8 *) CLK_4MHZ__CFG2)

#if defined(CLK_4MHZ__CFG3)
/* Analog clock phase configuration register */
#define CLK_4MHZ_PHASE              (* (reg8 *) CLK_4MHZ__CFG3)
#define CLK_4MHZ_PHASE_PTR          ((reg8 *) CLK_4MHZ__CFG3)
#endif /* defined(CLK_4MHZ__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define CLK_4MHZ_CLKEN_MASK         CLK_4MHZ__PM_ACT_MSK
#define CLK_4MHZ_CLKSTBY_MASK       CLK_4MHZ__PM_STBY_MSK

/* CFG2 field masks */
#define CLK_4MHZ_SRC_SEL_MSK        CLK_4MHZ__CFG2_SRC_SEL_MASK
#define CLK_4MHZ_MODE_MASK          (~(CLK_4MHZ_SRC_SEL_MSK))

#if defined(CLK_4MHZ__CFG3)
/* CFG3 phase mask */
#define CLK_4MHZ_PHASE_MASK         CLK_4MHZ__CFG3_PHASE_DLY_MASK
#endif /* defined(CLK_4MHZ__CFG3) */

#endif /* CY_CLOCK_CLK_4MHZ_H */


/* [] END OF FILE */
