/*******************************************************************************
* File Name: Monitoring_REF_DAC_PM.c  
* Version 1.90
*
* Description:
*  This file provides the power management source code to API for the
*  VDAC8.  
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Monitoring_REF_DAC.h"

static Monitoring_REF_DAC_backupStruct Monitoring_REF_DAC_backup;


/*******************************************************************************
* Function Name: Monitoring_REF_DAC_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void Monitoring_REF_DAC_SaveConfig(void) 
{
    if (!((Monitoring_REF_DAC_CR1 & Monitoring_REF_DAC_SRC_MASK) == Monitoring_REF_DAC_SRC_UDB))
    {
        Monitoring_REF_DAC_backup.data_value = Monitoring_REF_DAC_Data;
    }
}


/*******************************************************************************
* Function Name: Monitoring_REF_DAC_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void Monitoring_REF_DAC_RestoreConfig(void) 
{
    if (!((Monitoring_REF_DAC_CR1 & Monitoring_REF_DAC_SRC_MASK) == Monitoring_REF_DAC_SRC_UDB))
    {
        if((Monitoring_REF_DAC_Strobe & Monitoring_REF_DAC_STRB_MASK) == Monitoring_REF_DAC_STRB_EN)
        {
            Monitoring_REF_DAC_Strobe &= (uint8)(~Monitoring_REF_DAC_STRB_MASK);
            Monitoring_REF_DAC_Data = Monitoring_REF_DAC_backup.data_value;
            Monitoring_REF_DAC_Strobe |= Monitoring_REF_DAC_STRB_EN;
        }
        else
        {
            Monitoring_REF_DAC_Data = Monitoring_REF_DAC_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: Monitoring_REF_DAC_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  Monitoring_REF_DAC_backup.enableState:  Is modified depending on the enable 
*  state  of the block before entering sleep mode.
*
*******************************************************************************/
void Monitoring_REF_DAC_Sleep(void) 
{
    /* Save VDAC8's enable state */    
    if(Monitoring_REF_DAC_ACT_PWR_EN == (Monitoring_REF_DAC_PWRMGR & Monitoring_REF_DAC_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        Monitoring_REF_DAC_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        Monitoring_REF_DAC_backup.enableState = 0u;
    }
    
    Monitoring_REF_DAC_Stop();
    Monitoring_REF_DAC_SaveConfig();
}


/*******************************************************************************
* Function Name: Monitoring_REF_DAC_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Monitoring_REF_DAC_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void Monitoring_REF_DAC_Wakeup(void) 
{
    Monitoring_REF_DAC_RestoreConfig();
    
    if(Monitoring_REF_DAC_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        Monitoring_REF_DAC_Enable();

        /* Restore the data register */
        Monitoring_REF_DAC_SetValue(Monitoring_REF_DAC_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
